@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -79,13 +79,11 @@ cut_assert_equal_boolean_helper (cut_boolean     expected,
     if ((expected && actual) || (!expected && !actual)) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s == %s>\n"
-                                      "expected: <%s>\n"
-                                      "  actual: <%s>",
+        cut_set_expected(expected ? "true" : "false");
+        cut_set_actual(actual ? "true" : "false");
+        cut_test_fail(cut_take_printf("<%s == %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected ? "true" : "false",
-                                      actual ? "true" : "false"));
+                                      expression_actual));
     }
 }
 
@@ -96,13 +94,11 @@ cut_assert_not_equal_boolean_helper (cut_boolean     expected,
                                      const char     *expression_actual)
 {
     if ((expected && actual) || (!expected && !actual)) {
-        cut_test_fail(cut_take_printf("<%s != %s>\n"
-                                      "expected: <%s>\n"
-                                      "  actual: <%s>",
+        cut_set_expected(expected ? "true" : "false");
+        cut_set_actual(actual ? "true" : "false");
+        cut_test_fail(cut_take_printf("<%s != %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected ? "true" : "false",
-                                      actual ? "true" : "false"));
+                                      expression_actual));
     } else {
         cut_test_pass();
     }
@@ -127,9 +123,9 @@ cut_assert_null_string_helper (const char     *string,
     if (string == NULL) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("expected: <%s> is NULL\n"
-                                      "  actual: <%s>",
-                                      expression, string));
+        cut_set_expected("<NULL>");
+        cut_set_actual(string);
+        cut_test_fail(cut_take_printf("<%s> is NULL", expression));
     }
 }
 
@@ -154,12 +150,11 @@ cut_assert_equal_int_helper (long            expected,
     if (expected == actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s == %s>\n"
-                                      "expected: <%ld>\n"
-                                      "  actual: <%ld>",
+        cut_set_expected(cut_take_printf("%ld", expected));
+        cut_set_actual(cut_take_printf("%ld", actual));
+        cut_test_fail(cut_take_printf("<%s == %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -172,12 +167,11 @@ cut_assert_not_equal_int_helper (long            expected,
     if (expected != actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s != %s>\n"
-                                      "expected: <%ld>\n"
-                                      "  actual: <%ld>",
+        cut_set_expected(cut_take_printf("%ld", expected));
+        cut_set_actual(cut_take_printf("%ld", actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -190,12 +184,11 @@ cut_assert_equal_uint_helper (unsigned long   expected,
     if (expected == actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s == %s>\n"
-                                      "expected: <%lu>\n"
-                                      "  actual: <%lu>",
+        cut_set_expected(cut_take_printf("%lu", expected));
+        cut_set_actual(cut_take_printf("%lu", actual));
+        cut_test_fail(cut_take_printf("<%s == %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -208,12 +201,11 @@ cut_assert_not_equal_uint_helper (unsigned long   expected,
     if (expected != actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s != %s>\n"
-                                      "expected: <%lu>\n"
-                                      "  actual: <%lu>",
+        cut_set_expected(cut_take_printf("%lu", expected));
+        cut_set_actual(cut_take_printf("%lu", actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -226,12 +218,11 @@ cut_assert_equal_size_helper (size_t          expected,
     if (expected == actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s == %s>\n"
-                                      "expected: <%" G_GSIZE_FORMAT ">\n"
-                                      "  actual: <%" G_GSIZE_FORMAT ">",
+        cut_set_expected(cut_take_printf("%" G_GSIZE_FORMAT, expected));
+        cut_set_actual(cut_take_printf("%" G_GSIZE_FORMAT, actual));
+        cut_test_fail(cut_take_printf("<%s == %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -244,12 +235,11 @@ cut_assert_not_equal_size_helper (size_t          expected,
     if (expected != actual) {
         cut_test_pass();
     } else {
-        cut_test_fail(cut_take_printf("<%s != %s>\n"
-                                      "expected: <%" G_GSIZE_FORMAT ">\n"
-                                      "  actual: <%" G_GSIZE_FORMAT ">",
+        cut_set_expected(cut_take_printf("%" G_GSIZE_FORMAT, expected));
+        cut_set_actual(cut_take_printf("%" G_GSIZE_FORMAT, actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      expected, actual));
+                                      expression_actual));
     }
 }
 
@@ -364,15 +354,11 @@ cut_assert_equal_string_helper (const char     *expected,
         } else {
             const char *message;
 
-            message = cut_take_printf("<%s == %s>\n"
-                                      "expected: <%s>\n"
-                                      "  actual: <%s>",
+            message = cut_take_printf("<%s == %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      cut_utils_inspect_string(expected),
-                                      cut_utils_inspect_string(actual));
-            if (expected && actual)
-                message = cut_append_diff(message, expected, actual);
+                                      expression_actual);
+            cut_set_expected(expected);
+            cut_set_actual(actual);
             cut_test_fail(message);
         }
     }
@@ -399,15 +385,11 @@ cut_assert_not_equal_string_helper (const char     *expected,
         } else {
             const char *message;
 
-            message = cut_take_printf("<%s != %s>\n"
-                                      "expected: <%s>\n"
-                                      "  actual: <%s>",
+            message = cut_take_printf("<%s != %s>",
                                       expression_expected,
-                                      expression_actual,
-                                      cut_utils_inspect_string(expected),
-                                      cut_utils_inspect_string(actual));
-            if (expected && actual)
-                message = cut_append_diff(message, expected, actual);
+                                      expression_actual);
+            cut_set_expected(expected);
+            cut_set_actual(actual);
             cut_test_fail(message);
         }
     }
@@ -442,16 +424,12 @@ cut_assert_equal_substring_helper (const char     *expected,
 
             actual_substring = cut_take_string(g_strndup(actual, length));
             message =
-                cut_take_printf("<%s == (%s)[0..%s]>\n"
-                                "expected: <%s>\n"
-                                "  actual: <%s>",
+                cut_take_printf("<%s == (%s)[0..%s]>",
                                 expression_expected,
                                 expression_actual,
-                                expression_length,
-                                cut_utils_inspect_string(expected),
-                                cut_utils_inspect_string(actual_substring));
-            if (expected && actual_substring)
-                message = cut_append_diff(message, expected, actual_substring);
+                                expression_length);
+            cut_set_expected(expected);
+            cut_set_actual(actual_substring);
             cut_test_fail(message);
         }
     }
@@ -487,16 +465,12 @@ cut_assert_not_equal_substring_helper (const char     *expected,
             if (actual)
                 actual_substring = cut_take_string(g_strndup(actual, length));
             message =
-                cut_take_printf("<%s != (%s)[0..%s]>\n"
-                                "expected: <%s>\n"
-                                "  actual: <%s>",
+                cut_take_printf("<%s != (%s)[0..%s]>",
                                 expression_expected,
                                 expression_actual,
-                                expression_length,
-                                cut_utils_inspect_string(expected),
-                                cut_utils_inspect_string(actual_substring));
-            if (expected && actual_substring)
-                message = cut_append_diff(message, expected, actual_substring);
+                                expression_length);
+            cut_set_expected(expected);
+            cut_set_actual(actual_substring);
             cut_test_fail(message);
         }
     }
@@ -519,29 +493,23 @@ cut_assert_equal_memory_helper (const void     *expected,
         const char *message;
         const char *inspected_expected;
         const char *inspected_actual;
-        gsize max_diff_target_size = 8092;
 
         inspected_expected =
             cut_take_string(cut_utils_inspect_memory(expected, expected_size));
         inspected_actual =
             cut_take_string(cut_utils_inspect_memory(actual, actual_size));
         message = cut_take_printf(
-            "<%s(size: %s) == %s(size: %s)>\n"
-            "expected: <%s (size: %" G_GSIZE_FORMAT ")>\n"
-            "  actual: <%s (size: %" G_GSIZE_FORMAT ")>",
+            "<%s(size: %s) == %s(size: %s)>",
             expression_expected,
             expression_expected_size,
             expression_actual,
-            expression_actual_size,
-            inspected_expected,
-            expected_size,
-            inspected_actual,
-            actual_size);
-        if (0 < expected_size && expected_size < max_diff_target_size &&
-            0 < actual_size && actual_size < max_diff_target_size)
-            message = cut_append_diff(message,
-                                      inspected_expected,
-                                      inspected_actual);
+            expression_actual_size);
+        cut_set_expected(cut_take_printf("%s (size: %" G_GSIZE_FORMAT ")",
+                                         inspected_expected,
+                                         expected_size));
+        cut_set_actual(cut_take_printf("%s (size: %" G_GSIZE_FORMAT ")",
+                                       inspected_actual,
+                                       actual_size));
         cut_test_fail(message);
     }
 }
@@ -563,29 +531,21 @@ cut_assert_not_equal_memory_helper (const void     *expected,
         const char *message;
         const char *inspected_expected;
         const char *inspected_actual;
-        gsize max_diff_target_size = 8092;
 
         inspected_expected =
             cut_take_string(cut_utils_inspect_memory(expected, expected_size));
         inspected_actual =
             cut_take_string(cut_utils_inspect_memory(actual, actual_size));
         message = cut_take_printf(
-            "<%s(size: %s) != %s(size: %s)>\n"
-            "expected: <%s (size: %" G_GSIZE_FORMAT ")>\n"
-            "  actual: <%s (size: %" G_GSIZE_FORMAT ")>",
+            "<%s(size: %s) != %s(size: %s)>",
             expression_expected,
             expression_expected_size,
             expression_actual,
-            expression_actual_size,
-            inspected_expected,
-            expected_size,
-            inspected_actual,
-            actual_size);
-        if (0 < expected_size && expected_size < max_diff_target_size &&
-            0 < actual_size && actual_size < max_diff_target_size)
-            message = cut_append_diff(message,
-                                      inspected_expected,
-                                      inspected_actual);
+            expression_actual_size);
+        cut_set_expected(cut_take_printf("%s (size: %" G_GSIZE_FORMAT ")",
+                                         inspected_expected, expected_size));
+        cut_set_actual(cut_take_printf("%s (size: %" G_GSIZE_FORMAT ")",
+                                       inspected_actual, actual_size));
         cut_test_fail(message);
     }
 }
@@ -606,16 +566,11 @@ cut_assert_equal_string_array_helper (char          **expected,
 
         inspected_expected = cut_inspect_string_array(expected);
         inspected_actual = cut_inspect_string_array(actual);
-        message = cut_take_printf("<%s == %s>\n"
-                                  "expected: <%s>\n"
-                                  "  actual: <%s>",
+        message = cut_take_printf("<%s == %s>",
                                   expression_expected,
-                                  expression_actual,
-                                  inspected_expected,
-                                  inspected_actual);
-        if (expected && actual)
-            message = cut_append_diff(message,
-                                      inspected_expected, inspected_actual);
+                                  expression_actual);
+        cut_set_expected(inspected_expected);
+        cut_set_actual(inspected_actual);
         cut_test_fail(message);
     }
 }
