@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,6 +52,7 @@ typedef enum {
     MODE_ANALYZE
 } RunMode;
 
+static gboolean environment_initialized = FALSE;
 static gboolean initialized = FALSE;
 static RunMode mode = MODE_TEST;
 static gchar *test_directory = NULL;
@@ -72,6 +73,7 @@ static gchar *cutter_command_path = NULL;
 static gboolean fatal_failures = FALSE;
 static gboolean keep_opening_modules = FALSE;
 static gboolean enable_convenience_attribute_definition = FALSE;
+static gboolean stop_before_test = FALSE;
 
 static gboolean
 print_version (const gchar *option_name, const gchar *value,
@@ -159,27 +161,23 @@ static const GOptionEntry option_entries[] =
      N_("Enable convenience but danger "
         "'#{ATTRIBUTE_NAME}_#{TEST_NAME - 'test_' PREFIX}' "
         "attribute set function"), NULL},
+    {"stop-before-test", 0, 0, G_OPTION_ARG_NONE,
+     &stop_before_test,
+     N_("Set breakpoints at each line which invokes test. "
+        "You can step into a test function with your debugger easily."), NULL},
     {NULL}
 };
 
 void
-cut_init (int *argc, char ***argv)
+cut_init_environment (int *argc, char ***argv)
 {
-    int i;
-    GOptionContext *option_context;
-    GOptionGroup *main_group;
-    GError *error = NULL;
-    gchar *program_name, *parameter_string;
-
-    if (initialized)
+    if (environment_initialized)
         return;
 
-    initialized = TRUE;
+    environment_initialized = TRUE;
 
     cut_set_cutter_command_path((*argv)[0]);
 
-    original_argv = g_strdupv(*argv);
-
     setlocale(LC_ALL, "");
 
 #ifdef G_OS_WIN32
@@ -201,6 +199,25 @@ cut_init (int *argc, char ***argv)
         g_thread_init(NULL);
 
     gcut_init();
+}
+
+void
+cut_init (int *argc, char ***argv)
+{
+    int i;
+    GOptionContext *option_context;
+    GOptionGroup *main_group;
+    GError *error = NULL;
+    gchar *program_name, *parameter_string;
+
+    if (initialized)
+        return;
+
+    initialized = TRUE;
+
+    original_argv = g_strdupv(*argv);
+
+    cut_init_environment(argc, argv);
 
     cut_test_context_current_init();
 
@@ -220,7 +237,7 @@ cut_init (int *argc, char ***argv)
 
     main_group = g_option_group_new(NULL, NULL, NULL, option_context, NULL);
     g_option_group_add_entries(main_group, option_entries);
-    g_option_group_set_translation_domain(main_group, "cutter");
+    g_option_group_set_translation_domain(main_group, GETTEXT_PACKAGE);
     g_option_context_set_main_group(option_context, main_group);
 
     if (!g_option_context_parse(option_context, argc, argv, &error)) {
@@ -277,6 +294,17 @@ cut_init (int *argc, char ***argv)
     g_type_class_unref(g_type_class_ref(CUT_TYPE_TEST_CONTEXT));
 }
 
+void
+cut_quit_environment (void)
+{
+    if (!environment_initialized)
+        return;
+
+    gcut_quit();
+
+    environment_initialized = FALSE;
+}
+
 void
 cut_quit (void)
 {
@@ -302,7 +330,7 @@ cut_quit (void)
 
     cut_test_context_current_quit();
 
-    gcut_quit();
+    cut_quit_environment();
 
     initialized = FALSE;
 }
@@ -334,6 +362,7 @@ cut_create_run_context (void)
     cut_run_context_set_keep_opening_modules(run_context, keep_opening_modules);
     cut_run_context_set_enable_convenience_attribute_definition(run_context,
                                                                 enable_convenience_attribute_definition);
+    cut_run_context_set_stop_before_test(run_context, stop_before_test);
     cut_run_context_set_command_line_args(run_context, original_argv);
 
     return run_context;
