@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -41,23 +41,36 @@ typedef enum {
     CUT_TEST_RESULT_PENDING,
     CUT_TEST_RESULT_FAILURE,
     CUT_TEST_RESULT_ERROR,
+    CUT_TEST_RESULT_CRASH,
     CUT_TEST_RESULT_LAST
 } CutTestResultStatus;
 
-void            cut_test_context_current_set(CutTestContext *context);
-CutTestContext *cut_test_context_current_get(void);
+void            cut_test_context_current_push(CutTestContext *context);
+CutTestContext *cut_test_context_current_pop (void);
+CutTestContext *cut_test_context_current_peek(void);
 
+void  cut_test_context_keep_user_message    (CutTestContext *context);
+void  cut_test_context_set_user_message     (CutTestContext *context,
+                                             const char *format,
+                                             ...) CUT_GNUC_PRINTF(2, 3);
+void  cut_test_context_set_user_message_backward_compatibility
+                                            (CutTestContext *context,
+                                             const char *format,
+                                             ...);
+void  cut_test_context_set_user_message_va_list
+                                            (CutTestContext *context,
+                                             const char *format,
+                                             va_list args);
+void  cut_test_context_check_optional_assertion_message
+                                            (CutTestContext *context);
+void  cut_test_context_set_expected         (CutTestContext *context,
+                                             const char *expected);
+void  cut_test_context_set_actual           (CutTestContext *context,
+                                             const char *actual);
 void  cut_test_context_pass_assertion       (CutTestContext *context);
 void  cut_test_context_register_result      (CutTestContext *context,
                                              CutTestResultStatus status,
-                                             const char *message,
-                                             ...) /* CUT_GNUC_PRINTF(4, 5) */;
-void  cut_test_context_register_result_va_list
-                                            (CutTestContext *context,
-                                             CutTestResultStatus status,
-                                             const char *system_message,
-                                             const char *user_message_format,
-                                             va_list args);
+                                             const char *system_message);
 void  cut_test_context_long_jump            (CutTestContext *context) CUT_GNUC_NORETURN;
 
 const void *cut_test_context_take           (CutTestContext *context,
@@ -88,6 +101,9 @@ char        *cut_utils_inspect_memory       (const void *memory,
 
 cut_boolean  cut_utils_equal_string         (const char *string1,
                                              const char *string2);
+cut_boolean  cut_utils_equal_substring      (const char *string1,
+                                             const char *string2,
+                                             size_t      length);
 cut_boolean  cut_utils_equal_double         (double double1,
                                              double double2,
                                              double error);
@@ -99,6 +115,8 @@ const char  *cut_utils_inspect_string       (const char *string);
 cut_boolean  cut_utils_path_exist           (const char *path);
 char        *cut_utils_build_path           (const char *path,
                                              ...) CUT_GNUC_NULL_TERMINATED;
+char        *cut_utils_build_path_va_list   (const char *path,
+                                             va_list args);
 void         cut_utils_remove_path_recursive_force
                                             (const char *path);
 cut_boolean  cut_utils_regex_match          (const char *pattern,
@@ -113,15 +131,16 @@ char       *cut_test_context_build_fixture_data_path
                                              const char     *path,
                                              ...) CUT_GNUC_NULL_TERMINATED;
 
-const char *cut_utils_get_fixture_data_string(CutTestContext *context,
-                                              const char *path,
-                                              ...) CUT_GNUC_NULL_TERMINATED;
-
-void  cut_utils_get_fixture_data_string_and_path(CutTestContext *context,
-                                                 char **data,
-                                                 char **fixture_data_path,
-                                                 const char *path,
-                                                 ...) CUT_GNUC_NULL_TERMINATED;
+const char *cut_utils_get_fixture_data_string
+                                            (CutTestContext *context,
+                                             char **fixture_data_path,
+                                             const char *path,
+                                             ...) CUT_GNUC_NULL_TERMINATED;
+const char *cut_utils_get_fixture_data_string_va_list
+                                            (CutTestContext *context,
+                                             char **fixture_data_path,
+                                             const char *path,
+                                             va_list args);
 
 void  cut_test_context_add_data             (CutTestContext *context,
                                              const char     *first_data_name,
@@ -147,6 +166,7 @@ void  cut_test_context_set_fixture_data_dir (CutTestContext *context,
                                              ...) CUT_GNUC_NULL_TERMINATED;
 
 void        cut_test_context_push_backtrace (CutTestContext *context,
+                                             const char     *relative_path,
                                              const char     *file_name,
                                              unsigned int    line,
                                              const char     *function_name,
@@ -161,8 +181,12 @@ void        cut_test_context_get_last_backtrace
 
 char       *cut_diff_readable               (const char     *from,
                                              const char     *to);
-char       *cut_diff_folded_readable        (const char     *from,
+char       *cut_diff_readable_folded        (const char     *from,
                                              const char     *to);
+char       *cut_diff_unified                (const char     *from,
+                                             const char     *to,
+                                             const char     *from_label,
+                                             const char     *to_label);
 
 CutSubProcess *cut_utils_take_new_sub_process     (const char     *test_directory,
                                                    CutTestContext *test_context);
