@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -89,6 +89,8 @@ struct _CutTestContextPrivate
     gchar *user_message;
     guint user_message_keep_count;
     GMutex *mutex;
+    gchar *expected;
+    gchar *actual;
 };
 
 enum
@@ -257,6 +259,9 @@ cut_test_context_init (CutTestContext *context)
     priv->user_message_keep_count = 0;
 
     priv->mutex = g_mutex_new();
+
+    priv->expected = NULL;
+    priv->actual = NULL;
 }
 
 static void
@@ -284,6 +289,20 @@ clear_user_message (CutTestContextPrivate *priv)
     }
 }
 
+static void
+clear_additional_test_result_data (CutTestContextPrivate *priv)
+{
+    if (priv->expected) {
+        g_free(priv->expected);
+        priv->expected = NULL;
+    }
+
+    if (priv->actual) {
+        g_free(priv->actual);
+        priv->actual = NULL;
+    }
+}
+
 static void
 dispose (GObject *object)
 {
@@ -351,6 +370,8 @@ dispose (GObject *object)
         priv->mutex = NULL;
     }
 
+    clear_additional_test_result_data(priv);
+
     G_OBJECT_CLASS(cut_test_context_parent_class)->dispose(object);
 }
 
@@ -814,6 +835,10 @@ cut_test_context_register_result (CutTestContext *context,
                                  priv->backtrace);
     clear_user_message(priv);
 
+    cut_test_result_set_expected(result, priv->expected);
+    cut_test_result_set_actual(result, priv->actual);
+    clear_additional_test_result_data(priv);
+
     if (priv->test) {
         CutProcess *process;
         /* If the current procss is a child process, the pid is 0. */
@@ -1443,22 +1468,16 @@ cut_test_context_set_user_message_va_list (CutTestContext *context,
 }
 
 void
-cut_test_context_check_optional_assertion_message (CutTestContext *context,
-                                                   const char *message)
+cut_test_context_check_optional_assertion_message (CutTestContext *context)
 {
     CutTestContextPrivate *priv;
 
-    if (!message)
-        return;
-    if (message[0] == '\0')
-        return;
-
     priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
 
     clear_user_message(priv);
-    priv->user_message = g_strdup_printf("optional assertion message "
-                                         "on the current environment "
-                                         "is unavailable: <%s>", message);
+    priv->user_message = g_strdup("optional assertion message "
+                                  "on the current environment "
+                                  "is unavailable");
 }
 
 void
@@ -1467,6 +1486,28 @@ cut_test_context_keep_user_message (CutTestContext *context)
     CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_keep_count++;
 }
 
+void
+cut_test_context_set_expected (CutTestContext *context, const gchar *expected)
+{
+    CutTestContextPrivate *priv;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    if (priv->expected)
+        g_free(priv->expected);
+    priv->expected = g_strdup(expected);
+}
+
+void
+cut_test_context_set_actual (CutTestContext *context, const gchar *actual)
+{
+    CutTestContextPrivate *priv;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    if (priv->actual)
+        g_free(priv->actual);
+    priv->actual = g_strdup(actual);
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
