@@ -193,34 +193,6 @@ extern "C" {
                                              replacement)),             \
          cut_pop_backtrace))
 
-/**
- * cut_append_diff:
- * @message: the string to be appended diff.
- * @from: the original string.
- * @to: the modified string.
- *
- * Computes diff between @from and @to and append the diff
- * to @message. Returned string is owned by Cutter.
- *
- * Returns: @message with diff between @from and @to or same
- * as @message if the diff not interested. Don't free it.
- *
- * Since: 1.0.3
- */
-#define cut_append_diff(message, from, to)                      \
-    cut_take_string(cut_utils_append_diff(message, from, to))
-
-/**
- * cut_inspect_string_array:
- * @strings: the array of strings to be inspected.
- *
- * Formats @strings as human readable string that is owned by Cutter.
- *
- * Returns: a inspected string owned by Cutter. Don't free it.
- */
-#define cut_inspect_string_array(strings)                               \
-    cut_take_string(cut_utils_inspect_string_array(strings))
-
 /**
  * cut_set_fixture_data_dir:
  * @path: a first element of the path to the fixture data directory.
@@ -304,38 +276,6 @@ extern "C" {
 #define cut_build_path(...)                                            \
     cut_take_string(cut_utils_build_path(__VA_ARGS__))
 
-/**
- * cut_equal_string:
- * @string1: a string.
- * @string2: a string.
- *
- * Compare @string1 to @string2. @string1 and/or @string2
- * maybe %NULL.
- *
- * Returns: %CUT_TRUE if both @string1 and @string2 are %NULL or
- *          have the same contents; %CUT_FALSE otherwise.
- *
- * Since: 1.0.5
- */
-#define cut_equal_string(string1, string2)                              \
-    cut_utils_equal_string(string1, string2)
-
-/**
- * cut_equal_double:
- * @double1: a double value.
- * @double2: a double value.
- * @error: a double value that specifies error range.
- *
- * Compare @double1 to @double2 with @error range.
- *
- * Returns: %CUT_TRUE if |@double1 - @double2| <= @error;
- *          %CUT_FALSE otherwise.
- *
- * Since: 1.0.5
- */
-#define cut_equal_double(double1, double2, error)       \
-    cut_utils_equal_double(double1, double2, error)
-
 #ifdef __cplusplus
 }
 #endif
