@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -30,6 +30,8 @@
 #include <glib/gstdio.h>
 #ifdef G_OS_WIN32
 #  include <windows.h>
+#  include <io.h>
+#  define close _close
 #endif
 
 #include <errno.h>
@@ -37,7 +39,7 @@
 #include "cut-utils.h"
 #include "cut-sub-process.h"
 #include "cut-sub-process-group.h"
-#include "cut-diff.h"
+#include "cut-readable-differ.h"
 #include "cut-main.h"
 #include "cut-backtrace-entry.h"
 #include "../gcutter/gcut-public.h"
@@ -543,17 +545,17 @@ cut_utils_append_diff (const gchar *message, const gchar *from, const gchar *to)
     gchar *diff, *result;
 
     diff = cut_diff_readable(from, to);
-    if (cut_diff_is_interested(diff)) {
+    if (cut_diff_readable_is_interested(diff)) {
         result = g_strdup_printf("%s\n"
                                  "\n"
                                  "diff:\n"
                                  "%s",
                                  message, diff);
-        if (cut_diff_need_fold(diff)) {
+        if (cut_diff_readable_need_fold(diff)) {
             gchar *folded_diff, *original_result;
 
             original_result = result;
-            folded_diff = cut_diff_folded_readable(from, to);
+            folded_diff = cut_diff_readable_folded(from, to);
             result = g_strdup_printf("%s\n"
                                      "\n"
                                      "folded diff:\n"
@@ -728,6 +730,51 @@ cut_utils_parse_gdb_backtrace (const gchar *gdb_backtrace)
     return backtraces;
 }
 
+gchar *
+cut_utils_double_to_string (gdouble value)
+{
+    gint i;
+    gchar *string;
+
+    string = g_strdup_printf("%f", value);
+    for (i = 0; string[i]; i++) {
+        if (string[i] == ',')
+            string[i] = '.';
+    }
+
+    return string;
+}
+
+gint
+cut_utils_compare_string (gconstpointer data1, gconstpointer data2)
+{
+    if (data1 == NULL && data2 == NULL)
+        return 0;
+
+    if (data1 == NULL)
+        return -1;
+    if (data2 == NULL)
+        return 1;
+
+    return strcmp(data1, data2);
+}
+
+gint
+cut_utils_compare_direct (gconstpointer data1, gconstpointer data2)
+{
+    guint value1, value2;
+
+    value1 = GPOINTER_TO_UINT(data1);
+    value2 = GPOINTER_TO_UINT(data2);
+    if (value1 == value2) {
+        return 0;
+    } else if (value1 < value2) {
+        return -1;
+    } else {
+        return 1;
+    }
+}
+
 #ifdef G_OS_WIN32
 static gchar *win32_base_path = NULL;
 
