@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -183,11 +183,10 @@ test_equal_boolean (void)
     cut_assert_test_result_summary(run_context, 1, 3, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_equal_boolean()", NULL,
-                           "<CUT_TRUE == CUT_FALSE>\n"
-                           "expected: <true>\n"
-                           "  actual: <false>",
-                           FAIL_LOCATION,
-                           "stub_equal_boolean");
+                           "<CUT_TRUE == CUT_FALSE>",
+                           "true", "false",
+                           FAIL_LOCATION, "stub_equal_boolean",
+                           NULL);
 }
 
 static void
@@ -208,11 +207,10 @@ test_not_equal_boolean (void)
     cut_assert_test_result_summary(run_context, 1, 3, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_not_equal_boolean()", NULL,
-                           "<CUT_TRUE != 100>\n"
-                           "expected: <true>\n"
-                           "  actual: <true>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_boolean");
+                           "<CUT_TRUE != 100>",
+                           "true", "true",
+                           FAIL_LOCATION, "stub_not_equal_boolean",
+                           NULL);
 }
 
 static void
@@ -231,11 +229,10 @@ test_equal_int (void)
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_equal_int()", NULL,
-                           "<2 + 3 == 3 + 4>\n"
-                           "expected: <5>\n"
-                           "  actual: <7>",
-                           FAIL_LOCATION,
-                           "stub_equal_int");
+                           "<2 + 3 == 3 + 4>",
+                           "5", "7",
+                           FAIL_LOCATION, "stub_equal_int",
+                           NULL);
 }
 
 static void
@@ -254,11 +251,10 @@ test_not_equal_int (void)
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_not_equal_int()", NULL,
-                           "<2 + 3 != 3 + 2>\n"
-                           "expected: <5>\n"
-                           "  actual: <5>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_int");
+                           "<2 + 3 != 3 + 2>",
+                           "5", "5",
+                           FAIL_LOCATION, "stub_not_equal_int",
+                           NULL);
 }
 
 static void
@@ -276,11 +272,10 @@ test_equal_uint (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_equal_uint()", NULL,
-                           "<2 + 3 == 3 + 4>\n"
-                           "expected: <5>\n"
-                           "  actual: <7>",
-                           FAIL_LOCATION,
-                           "stub_equal_uint");
+                           "<2 + 3 == 3 + 4>",
+                           "5", "7",
+                           FAIL_LOCATION, "stub_equal_uint",
+                           NULL);
 }
 
 static void
@@ -298,11 +293,10 @@ test_not_equal_uint (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_not_equal_uint()", NULL,
-                           "<2 + 3 != 3 + 2>\n"
-                           "expected: <5>\n"
-                           "  actual: <5>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_uint");
+                           "<2 + 3 != 3 + 2>",
+                           "5", "5",
+                           FAIL_LOCATION, "stub_not_equal_uint",
+                           NULL);
 }
 
 static void
@@ -320,11 +314,10 @@ test_equal_size (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_equal_size()", NULL,
-                           "<1 == 10>\n"
-                           "expected: <1>\n"
-                           "  actual: <10>",
-                           FAIL_LOCATION,
-                           "stub_equal_size");
+                           "<1 == 10>",
+                           "1", "10",
+                           FAIL_LOCATION, "stub_equal_size",
+                           NULL);
 }
 
 static void
@@ -342,11 +335,10 @@ test_not_equal_size (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_not_equal_size()", NULL,
-                           "<2 + 3 != 3 + 2>\n"
-                           "expected: <5>\n"
-                           "  actual: <5>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_size");
+                           "<2 + 3 != 3 + 2>",
+                           "5", "5",
+                           FAIL_LOCATION, "stub_not_equal_size",
+                           NULL);
 }
 
 static void
@@ -365,11 +357,10 @@ test_equal_string (void)
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "assert-equal-string", NULL,
-                           "<\"abc\" == \"ABC\">\n"
-                           "expected: <abc>\n"
-                           "  actual: <ABC>",
-                           FAIL_LOCATION,
-                           "stub_equal_string");
+                           "<\"abc\" == \"ABC\">",
+                           "abc", "ABC",
+                           FAIL_LOCATION, "stub_equal_string",
+                           NULL);
 }
 
 static void
@@ -389,11 +380,10 @@ test_not_equal_string (void)
     cut_assert_test_result_summary(run_context, 1, 3, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "assert-not-equal-string", NULL,
-                           "<\"abc\" != \"abc\">\n"
-                           "expected: <abc>\n"
-                           "  actual: <abc>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_string");
+                           "<\"abc\" != \"abc\">",
+                           "abc", "abc",
+                           FAIL_LOCATION, "stub_not_equal_string",
+                           NULL);
 }
 
 static void
@@ -412,6 +402,8 @@ test_equal_string_with_diff (void)
                      &test_result);
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 0, 0, 1, 0, 0, 0, 0);
+    cut_assert_equal_string("<\"abc def ghi jkl\" == \"abc DEF ghi jkl\">",
+                            cut_test_result_get_system_message(test_result));
     cut_assert_equal_string("<\"abc def ghi jkl\" == \"abc DEF ghi jkl\">\n"
                             "expected: <abc def ghi jkl>\n"
                             "  actual: <abc DEF ghi jkl>\n"
@@ -421,7 +413,7 @@ test_equal_string_with_diff (void)
                             "?     ^^^\n"
                             "+ abc DEF ghi jkl\n"
                             "?     ^^^",
-                            cut_test_result_get_system_message(test_result));
+                            cut_test_result_get_message(test_result));
 }
 
 static void
@@ -457,6 +449,29 @@ test_equal_string_with_folded_diff (void)
                      &test_result);
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 0, 0, 1, 0, 0, 0, 0);
+    cut_assert_equal_string("<"
+                            "\"0123456789\" "
+                            "\"1123456789\" "
+                            "\"2123456789\" "
+                            "\"3123456789\" "
+                            "\"4123456789\" "
+                            "\"5123456789\" "
+                            "\"6123456789\" "
+                            "\"7123456789\" "
+                            "\"8123456789\""
+                            " == "
+                            "\"0000000000\" "
+                            "\"1123456789\" "
+                            "\"2123456789\" "
+                            "\"3123456789\" "
+                            "\"4123456789\" "
+                            "\"5123456789\" "
+                            "\"6123456789\" "
+                            "\"7123456789\" "
+                            "\"8123456789\""
+                            ">",
+                            cut_test_result_get_system_message(test_result));
+
     cut_assert_equal_string("<"
                             "\"0123456789\" "
                             "\"1123456789\" "
@@ -544,7 +559,7 @@ test_equal_string_with_folded_diff (void)
                             "?  ^^^^^^^^^\n"
                             "  89"
                             "8123456789",
-                            cut_test_result_get_system_message(test_result));
+                            cut_test_result_get_message(test_result));
 }
 
 static void
@@ -573,17 +588,11 @@ test_equal_substring (void)
                            "equal-substring", NULL,
                            "<\"0123456789\" == "
                            "(actual_string + strlen(\"0000\") + 1)"
-                           "[0..strlen(\"0123456789\")]>\n"
-                           "expected: <0123456789>\n"
-                           "  actual: <1234567899>\n"
-                           "\n"
-                           "diff:\n"
-                           "- 0123456789\n"
-                           "? -\n"
-                           "+ 1234567899\n"
-                           "?          +",
-                           FAIL_LOCATION,
-                           "stub_equal_substring");
+                           "[0..strlen(\"0123456789\")]>",
+                           "0123456789",
+                           "1234567899",
+                           FAIL_LOCATION, "stub_equal_substring",
+                           NULL);
 }
 
 static void
@@ -614,11 +623,11 @@ test_not_equal_substring (void)
                            "not-equal-substring", NULL,
                            "<\"0123456789\" != "
                            "(actual_string + strlen(\"0000\"))"
-                           "[0..strlen(\"0123456789\")]>\n"
-                           "expected: <0123456789>\n"
-                           "  actual: <0123456789>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_substring");
+                           "[0..strlen(\"0123456789\")]>",
+                           "0123456789",
+                           "0123456789",
+                           FAIL_LOCATION, "stub_not_equal_substring",
+                           NULL);
 }
 
 static void
@@ -632,20 +641,31 @@ stub_equal_double (void)
 void
 test_equal_double (void)
 {
+    gdouble expected = 1.02;
+    gdouble actual = 1.04;
+    gdouble error = 0.01;
+
     test = cut_test_new("cut_assert_equal_double()", stub_equal_double);
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
-    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
-                           "cut_assert_equal_double()", NULL,
-                           "<1.02-0.01 <= 1.04 <= 1.02+0.01>\n"
-                           "expected: <1.02>\n"
-                           "   error: <0.01>\n"
-                           "     min: <1.01>\n"
-                           "     max: <1.03>\n"
-                           "  actual: <1.04>\n"
-                           "relation: <min < max < actual>",
-                           FAIL_LOCATION,
-                           "stub_equal_double");
+    cut_assert_test_result(
+        run_context, 0, CUT_TEST_RESULT_FAILURE,
+        "cut_assert_equal_double()", NULL,
+        cut_take_printf("<1.02-0.01 <= 1.04 <= 1.02+0.01>\n"
+                        "expected: <%g>\n"
+                        "   error: <%g>\n"
+                        "     min: <%g>\n"
+                        "     max: <%g>\n"
+                        "  actual: <%g>\n"
+                        "relation: <min < max < actual>",
+                        expected,
+                        error,
+                        expected - error,
+                        expected + error,
+                        actual),
+        NULL, NULL,
+        FAIL_LOCATION, "stub_equal_double",
+        NULL);
 }
 
 static void
@@ -658,20 +678,31 @@ stub_not_equal_double (void)
 void
 test_not_equal_double (void)
 {
+    gdouble expected = 1.01;
+    gdouble actual = 1.02;
+    gdouble error = 0.1;
+
     test = cut_test_new("cut_assert_not_equal_double()", stub_not_equal_double);
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
-    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
-                           "cut_assert_not_equal_double()", NULL,
-                           "<(1.02 < 1.01-0.1) && (1.01+0.1 < 1.02)>\n"
-                           "expected: <1.01>\n"
-                           "   error: <0.1>\n"
-                           "     min: <0.91>\n"
-                           "     max: <1.11>\n"
-                           "  actual: <1.02>\n"
-                           "relation: <min < actual < max>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_double");
+    cut_assert_test_result(
+        run_context, 0, CUT_TEST_RESULT_FAILURE,
+        "cut_assert_not_equal_double()", NULL,
+        cut_take_printf("<(1.02 < 1.01-0.1) && (1.01+0.1 < 1.02)>\n"
+                        "expected: <%g>\n"
+                        "   error: <%g>\n"
+                        "     min: <%g>\n"
+                        "     max: <%g>\n"
+                        "  actual: <%g>\n"
+                        "relation: <min < actual < max>",
+                        expected,
+                        error,
+                        expected - error,
+                        expected + error,
+                        actual),
+        NULL, NULL,
+        FAIL_LOCATION, "stub_not_equal_double",
+        NULL);
 }
 
 void
@@ -706,8 +737,9 @@ test_operator_int (void)
                            "stub-operator-int", NULL,
                            "expected: <1 + 1> >= <2 + 4>\n"
                            "  actual: <2> >= <6>",
-                           FAIL_LOCATION,
-                           "stub_operator_int");
+                           NULL, NULL,
+                           FAIL_LOCATION, "stub_operator_int",
+                           NULL);
 }
 
 static void
@@ -730,8 +762,9 @@ test_operator_uint (void)
                            "stub-operator-uint", NULL,
                            "expected: <1 + 1> >= <2 + 4>\n"
                            "  actual: <2> >= <6>",
-                           FAIL_LOCATION,
-                           "stub_operator_uint");
+                           NULL, NULL,
+                           FAIL_LOCATION, "stub_operator_uint",
+                           NULL);
 }
 
 static void
@@ -754,8 +787,9 @@ test_operator_size (void)
                            "cut_assert_operator_size()", NULL,
                            "expected: <1 + 1> >= <2 + 4>\n"
                            "  actual: <2> >= <6>",
-                           FAIL_LOCATION,
-                           "stub_operator_size");
+                           NULL, NULL,
+                           FAIL_LOCATION, "stub_operator_size",
+                           NULL);
 }
 
 static void
@@ -768,17 +802,25 @@ stub_operator_double (void)
 void
 test_operator_double (void)
 {
+    gdouble lhs, rhs;
+
+    lhs = 1.1 + 1.1;
+    rhs = 2.2 + 4.4;
+
     test = cut_test_new("stub-operator-double", stub_operator_double);
     cut_assert_not_null(test);
 
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
-    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
-                           "stub-operator-double", NULL,
-                           "expected: <1.1 + 1.1> >= <2.2 + 4.4>\n"
-                           "  actual: <2.2> >= <6.6>",
-                           FAIL_LOCATION,
-                           "stub_operator_double");
+    cut_assert_test_result(
+        run_context, 0, CUT_TEST_RESULT_FAILURE,
+        "stub-operator-double", NULL,
+        cut_take_printf("expected: <1.1 + 1.1> >= <2.2 + 4.4>\n"
+                        "  actual: <%g> >= <%g>",
+                        lhs, rhs),
+        NULL, NULL,
+        FAIL_LOCATION, "stub_operator_double",
+        NULL);
 }
 
 static void
@@ -807,12 +849,12 @@ test_equal_memory (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "stub-equal-memory", NULL,
                            "<expected(size: sizeof(expected)) == "
-                           "actual(size: sizeof(actual))>\n"
-                           "expected: <0x00 0x01 0x02 0x03 0x04 (size: 5)>\n"
-                           "  actual: <0x00 0x01 0x02 0x03 0x04 "
-                           "0x12 0x10 0x0e 0x0c 0x0a (size: 10)>",
-                           FAIL_LOCATION,
-                           "stub_equal_memory");
+                           "actual(size: sizeof(actual))>",
+                           "0x00 0x01 0x02 0x03 0x04 (size: 5)",
+                           "0x00 0x01 0x02 0x03 0x04 "
+                           "0x12 0x10 0x0e 0x0c 0x0a (size: 10)",
+                           FAIL_LOCATION, "stub_equal_memory",
+                           NULL);
 }
 
 static void
@@ -841,20 +883,37 @@ test_not_equal_memory (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "stub-not-equal-memory", NULL,
                            "<expected(size: sizeof(expected)) != "
-                           "actual(size: sizeof(expected))>\n"
-                           "expected: <0x00 0x01 0x02 0x03 0x04 (size: 5)>\n"
-                           "  actual: <0x00 0x01 0x02 0x03 0x04 (size: 5)>",
-                           FAIL_LOCATION,
-                           "stub_not_equal_memory");
+                           "actual(size: sizeof(expected))>",
+                           "0x00 0x01 0x02 0x03 0x04 (size: 5)",
+                           "0x00 0x01 0x02 0x03 0x04 (size: 5)",
+                           FAIL_LOCATION, "stub_not_equal_memory",
+                           NULL);
+}
+
+static void
+stub_equal_string_array (void)
+{
+    gchar *strings1[] = {"a", "b", "c", NULL};
+    gchar *strings2[] = {"a", "b", "c", "d", NULL};
+
+    cut_assert_equal_string_array(strings1, strings1);
+    cut_assert_equal_string_array(strings2, strings2);
+    MARK_FAIL(cut_assert_equal_string_array(strings1, strings2));
 }
 
 void
 test_equal_string_array (void)
 {
-    gchar *strings1[] = {"a", "b", "c", NULL};
-    gchar *strings2[] = {"a", "b", "c", NULL};
-
-    cut_assert_equal_string_array(strings1, strings2);
+    test = cut_test_new("stub-equal-string-array", stub_equal_string_array);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "stub-equal-string-array", NULL,
+                           "<strings1 == strings2>",
+                           "[\"a\", \"b\", \"c\"]",
+                           "[\"a\", \"b\", \"c\", \"d\"]",
+                           FAIL_LOCATION, "stub_equal_string_array",
+                           NULL);
 }
 
 void
@@ -889,8 +948,9 @@ test_error (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_ERROR,
                            "stub-error-test",
                            "This test should error", NULL,
-                           FAIL_LOCATION,
-                           "stub_error");
+                           NULL, NULL,
+                           FAIL_LOCATION, "stub_error",
+                           NULL);
 }
 
 static void
@@ -1008,15 +1068,14 @@ test_assert_message (void)
 static void
 stub_assert_message_with_format_string (void)
 {
-    cut_assert_equal_string("%s", "%d",
-                            "%s and %s have format string",
-                            "expected", "actual");
+    MARK_FAIL(cut_assert_equal_string("%s", "%d",
+                                      "%s and %s have format string",
+                                      "expected", "actual"));
 }
 
 void
 test_assert_message_with_format_string (void)
 {
-    /* FIXME: use cut_assert_test_result_summary() */
     test = cut_test_new("stub-assert-message-with-string",
                         stub_assert_message_with_format_string);
     cut_assert_not_null(test);
@@ -1027,17 +1086,16 @@ test_assert_message_with_format_string (void)
     g_signal_handlers_disconnect_by_func(test,
                                          G_CALLBACK(cb_collect_result),
                                          &test_result);
-    cut_assert_not_null(test_result,
-                        "Could not get a CutTestResult object "
-                        "since \"failure\" signal was not emitted.");
-    cut_assert_equal_int(CUT_TEST_RESULT_FAILURE,
-                         cut_test_result_get_status(test_result));
-    cut_assert_equal_string("<\"%s\" == \"%d\">\n"
-                            "expected: <%s>\n"
-                            "  actual: <%d>",
-                            cut_test_result_get_system_message(test_result));
-    cut_assert_equal_string("expected and actual have format string",
-                            cut_test_result_get_user_message(test_result));
+
+    cut_assert_test_result_summary(run_context, 1, 0, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "stub-assert-message-with-string",
+                           "expected and actual have format string",
+                           "<\"%s\" == \"%d\">",
+                           "%s", "%d",
+                           FAIL_LOCATION,
+                           "stub_assert_message_with_format_string",
+                           NULL);
 }
 
 static gboolean
@@ -1089,18 +1147,24 @@ test_failure_from_nested_function (void)
 }
 
 static void
-null_string_assertions (void)
+stub_null_string (void)
 {
     cut_assert_null_string(NULL);
-    cut_assert_null_string("");
+    MARK_FAIL(cut_assert_null_string(""));
 }
 
 void
 test_null_string (void)
 {
-    test = cut_test_new("assert-null-string", null_string_assertions);
+    test = cut_test_new("assert-null-string", stub_null_string);
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "assert-null-string", NULL,
+                           "<\"\"> is NULL",
+                           "<NULL>", "",
+                           FAIL_LOCATION, "stub_null_string",
+                           NULL);
 }
 
 static void
